# coding: utf-8

"""
    marax-server-sdk

    Marax Server SDK to send transactional events from client server to marax server  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: team@marax.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import marax_server_sdk
from marax_server_sdk.api.reward_api import RewardApi  # noqa: E501
from marax_server_sdk.rest import ApiException


class TestRewardApi(unittest.TestCase):
    """RewardApi unit test stubs"""

    def setUp(self):
        self.api = marax_server_sdk.api.reward_api.RewardApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_process_event(self):
        """Test case for process_event

        Perform reward post-processing  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
